@@ -143,7 +143,7 @@ def windowfunc(strfunc):
     @wraps(strfunc)
     def qfunc(q0, *args, **kwargs):
         args = L(*args).fmap(lambda x: getattr(q0.columns, x) if type(x) is str else x)
-        return q0.aggregate(lambda x: exprfunc(*args, **kwargs))
+        return q0.aggregate(lambda x: exprfunc(*args, **kwargs), ungroup=False)
     setattr(Query, strfunc.__name__[:-1], qfunc)
     @wraps(strfunc)
     def colfunc(col, *args, **kwargs):
