@@ -203,10 +203,10 @@ class Query(Table, Monad):
     
     # %% ^━━━━━━━━━━━━━━ PUBLIC FUNCTIONS ━━━━━━━━━━━━━━━^
     
-    def aggregate(self, aggfunc=None, iswindow=False, existsq=False, lj=True, distinct=False):
+    def aggregate(self, aggfunc=None, iswindow=False, existsq=False, lj=True, distinct=False, ungroup=True):
         # Aggregate a query into a single row
         if aggfunc is not None:
-            return self.fmap(aggfunc).aggregate()
+            return self.fmap(aggfunc).aggregate(ungroup=ungroup)
         res = Columns()
         newsource = copy(self)
         for key, expr in newsource.columns.items():
@@ -216,7 +216,7 @@ class Query(Table, Monad):
             del newsource.columns[key]
             newsource.columns[dummylabel] = expr
             # SUPER IMPORTANT POINT: REMOVE A GROUP BY HERE
-            newsource.ungroupby()
+            if ungroup: newsource.ungroupby()
         
         if len(res) == 1 and not newsource.groupbys and not res.values().filter(lambda x: type(x.getRef()) is WindowExpr):
             newsource = deepcopy(newsource)
