@@ -627,7 +627,7 @@ def reduceQuery(self, debug=False, subquery=False):
         print(self.sql(reduce=False, debug=True))        
     
     # if the groupbys are left joined, then make the query left joined
-    if self.isQuery() and self.groupbys.getTables().fmap(lambda x: x.leftjoin).all():
+    if self.isQuery() and self.groupbys and self.groupbys.getTables().fmap(lambda x: x.leftjoin).all():
         self.leftjoin = True        
         for table in self.groupbys.getTables():
             table.leftjoin = False
